@@ -5,51 +5,13 @@ use strict;
 
 use 5.008;
 
-=head1 NAME
-
-Games::ABC_Path::Solver::Board - handles an ABC Path board.
-
-=head1 VERSION
-
-Version 0.4.1
-
-=cut
 
 our $VERSION = '0.4.1';
 
-=head1 SYNOPSIS
-
-    use strict;
-    use warnings;
-
-    my $board_fn = shift(@ARGV);
-
-    if (!defined ($board_fn))
-    {
-        die "Filename not specified - usage: abc-path-solver.pl [filename]!";
-    }
-
-    my $solver = Games::ABC_Path::Solver::Board->input_from_file($board_fn);
-    # Now let's do a neighbourhood inferring of the board.
-
-    $solver->solve;
-
-    foreach my $move (@{$solver->get_moves})
-    {
-        print +(' => ' x $move->get_depth()), $move->get_text(), "\n";
-    }
-
-=head1 FUNCTIONS
-
-=head2 new
-
-The constructor.
-
-=cut
 
 use Carp;
 
-use base 'Games::ABC_Path::Solver::Base';
+use parent 'Games::ABC_Path::Solver::Base';
 
 use Games::ABC_Path::Solver::Constants;
 use Games::ABC_Path::Solver::Move::LastRemainingCellForLetter;
@@ -142,12 +104,6 @@ sub _add_move {
     return;
 }
 
-=head2 get_successful_layouts()
-
-Returns a copy of the successful layouts. Each one of them is a completed
-L<Games::ABC_Path::Solver::Board> object.
-
-=cut
 
 sub get_successful_layouts {
     my ($self) = @_;
@@ -339,12 +295,6 @@ sub _get_possible_letter_indexes
     ];
 }
 
-=head2 $board->get_possible_letters_for_cell($x,$y)
-
-Returns an array reference of the possible letters for the cell ($x,$y) where
-$x and $y are in the range 0..4 and the letters are their letter names.
-
-=cut
 
 sub get_possible_letters_for_cell
 {
@@ -550,11 +500,6 @@ sub _clone
         );
 }
 
-=head2 $board->solve()
-
-Performs the actual solution. Should be called after input.
-
-=cut
 
 sub solve
 {
@@ -884,11 +829,6 @@ sub _get_results_text_table
     );
 }
 
-=head2 $self->get_successes_text_tables()
-
-This returns a textual representation of the successful layouts.
-
-=cut
 
 sub get_successes_text_tables
 {
@@ -897,26 +837,6 @@ sub get_successes_text_tables
     return [map { $_->_get_results_text_table() } @{$self->get_successful_layouts()}];
 }
 
-=head2 my $board = Games::ABC_Path::Solver::Board->input_from_file($filename)
-
-Inputs the board from the C<$filename> file path containing a representation
-of the initial board.
-
-Sample boards can be found in the distribution under C<t/layouts/> .
-
-Here is the description of their formats. The first line should be the
-magic string C<ABC Path Solver Layout Version 1:> , and the next line should
-be a row of 7 letters, the first being a hint for the top-left-to-bottom-right
-perpendicular, the last being a hint for the top-right-to-bottom-left
-perpendicular and the rest of the letters being vertical hints.
-
-After that, there are 5 rows of horizontal hints being a letter, 5 spaces
-and another letter. On one of the squares one can put a letter instead of a
-space, to indicate it must be there.
-
-The last row is another row of vertical hints and perpendicular hints.
-
-=cut
 
 sub input_from_file
 {
@@ -945,12 +865,6 @@ sub input_from_file
     return $class->input_from_v1_string($layout_string);
 }
 
-=head2 my $board = Games::ABC_Path::Solver::Board->input_from_v1_string($layout_string)
-
-This is a class method that inputs a version 1 string (as specified in
-L<input_from_file> only without the opening magic line.)
-
-=cut
 
 sub input_from_v1_string
 {
@@ -963,12 +877,6 @@ sub input_from_v1_string
     return $self;
 }
 
-=head2 $board->get_moves()
-
-Returns the moves performed by the board. Each move is an
-object of a L<Games::ABC_Path::Solver::Move> sub-class.
-
-=cut
 
 sub get_moves
 {
@@ -977,6 +885,102 @@ sub get_moves
     return [@{ $self->_moves }];
 }
 
+
+1; # End of Games::ABC_Path::Solver::Board
+
+__END__
+
+=pod
+
+=encoding UTF-8
+
+=head1 NAME
+
+Games::ABC_Path::Solver::Board - handles an ABC Path board.
+
+=head1 VERSION
+
+version 0.6.0
+
+=head1 SYNOPSIS
+
+    use strict;
+    use warnings;
+
+    my $board_fn = shift(@ARGV);
+
+    if (!defined ($board_fn))
+    {
+        die "Filename not specified - usage: abc-path-solver.pl [filename]!";
+    }
+
+    my $solver = Games::ABC_Path::Solver::Board->input_from_file($board_fn);
+    # Now let's do a neighbourhood inferring of the board.
+
+    $solver->solve;
+
+    foreach my $move (@{$solver->get_moves})
+    {
+        print +(' => ' x $move->get_depth()), $move->get_text(), "\n";
+    }
+
+=head1 VERSION
+
+Version 0.4.1
+
+=head1 FUNCTIONS
+
+=head2 new
+
+The constructor.
+
+=head2 get_successful_layouts()
+
+Returns a copy of the successful layouts. Each one of them is a completed
+L<Games::ABC_Path::Solver::Board> object.
+
+=head2 $board->get_possible_letters_for_cell($x,$y)
+
+Returns an array reference of the possible letters for the cell ($x,$y) where
+$x and $y are in the range 0..4 and the letters are their letter names.
+
+=head2 $board->solve()
+
+Performs the actual solution. Should be called after input.
+
+=head2 $self->get_successes_text_tables()
+
+This returns a textual representation of the successful layouts.
+
+=head2 my $board = Games::ABC_Path::Solver::Board->input_from_file($filename)
+
+Inputs the board from the C<$filename> file path containing a representation
+of the initial board.
+
+Sample boards can be found in the distribution under C<t/layouts/> .
+
+Here is the description of their formats. The first line should be the
+magic string C<ABC Path Solver Layout Version 1:> , and the next line should
+be a row of 7 letters, the first being a hint for the top-left-to-bottom-right
+perpendicular, the last being a hint for the top-right-to-bottom-left
+perpendicular and the rest of the letters being vertical hints.
+
+After that, there are 5 rows of horizontal hints being a letter, 5 spaces
+and another letter. On one of the squares one can put a letter instead of a
+space, to indicate it must be there.
+
+The last row is another row of vertical hints and perpendicular hints.
+
+=head2 my $board = Games::ABC_Path::Solver::Board->input_from_v1_string($layout_string)
+
+This is a class method that inputs a version 1 string (as specified in
+L<input_from_file> only without the opening magic line.)
+
+=head2 $board->get_moves()
+
+Returns the moves performed by the board. Each move is an
+object of a L<Games::ABC_Path::Solver::Move> sub-class.
+
 =head1 AUTHOR
 
 Shlomi Fish, C<< <shlomif at cpan.org> >>
@@ -987,16 +991,12 @@ Please report any bugs or feature requests to C<bug-games-abc_path-solver at rt.
 the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Games-ABC_Path-Solver>.  I will be notified, and then you'll
 automatically be notified of progress on your bug as I make changes.
 
-
-
-
 =head1 SUPPORT
 
 You can find documentation for this module with the perldoc command.
 
     perldoc Games::ABC_Path::Solver::Board
 
-
 You can also look for information at:
 
 =over 4
@@ -1019,10 +1019,8 @@ L<http://search.cpan.org/dist/Games-ABC_Path-Solver/>
 
 =back
 
-
 =head1 ACKNOWLEDGEMENTS
 
-
 =head1 COPYRIGHT & LICENSE
 
 Copyright 2010 Shlomi Fish.
@@ -1051,7 +1049,132 @@ WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
 OTHER DEALINGS IN THE SOFTWARE.
 
+=head1 AUTHOR
+
+Shlomi Fish <shlomif@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2018 by Shlomi Fish.
+
+This is free software, licensed under:
+
+  The MIT (X11) License
+
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website
+L<https://github.com/shlomif/games-abc_path-solver/issues>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
+=for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
+
+=head1 SUPPORT
+
+=head2 Perldoc
+
+You can find documentation for this module with the perldoc command.
+
+  perldoc Games::ABC_Path::Solver::Board
+
+=head2 Websites
+
+The following websites have more information about this module, and may be of help to you. As always,
+in addition to those websites please use your favorite search engine to discover more resources.
+
+=over 4
+
+=item *
+
+MetaCPAN
+
+A modern, open-source CPAN search engine, useful to view POD in HTML format.
+
+L<https://metacpan.org/release/Games-ABC_Path-Solver>
+
+=item *
+
+Search CPAN
+
+The default CPAN search engine, useful to view POD in HTML format.
+
+L<http://search.cpan.org/dist/Games-ABC_Path-Solver>
+
+=item *
+
+RT: CPAN's Bug Tracker
+
+The RT ( Request Tracker ) website is the default bug/issue tracking system for CPAN.
+
+L<https://rt.cpan.org/Public/Dist/Display.html?Name=Games-ABC_Path-Solver>
+
+=item *
+
+AnnoCPAN
+
+The AnnoCPAN is a website that allows community annotations of Perl module documentation.
+
+L<http://annocpan.org/dist/Games-ABC_Path-Solver>
+
+=item *
+
+CPAN Ratings
+
+The CPAN Ratings is a website that allows community ratings and reviews of Perl modules.
+
+L<http://cpanratings.perl.org/d/Games-ABC_Path-Solver>
+
+=item *
+
+CPANTS
+
+The CPANTS is a website that analyzes the Kwalitee ( code metrics ) of a distribution.
+
+L<http://cpants.cpanauthors.org/dist/Games-ABC_Path-Solver>
+
+=item *
+
+CPAN Testers
+
+The CPAN Testers is a network of smoke testers who run automated tests on uploaded CPAN distributions.
+
+L<http://www.cpantesters.org/distro/G/Games-ABC_Path-Solver>
+
+=item *
+
+CPAN Testers Matrix
+
+The CPAN Testers Matrix is a website that provides a visual overview of the test results for a distribution on various Perls/platforms.
+
+L<http://matrix.cpantesters.org/?dist=Games-ABC_Path-Solver>
+
+=item *
+
+CPAN Testers Dependencies
+
+The CPAN Testers Dependencies is a website that shows a chart of the test results of all dependencies for a distribution.
+
+L<http://deps.cpantesters.org/?module=Games::ABC_Path::Solver>
+
+=back
+
+=head2 Bugs / Feature Requests
+
+Please report any bugs or feature requests by email to C<bug-games-abc_path-solver at rt.cpan.org>, or through
+the web interface at L<https://rt.cpan.org/Public/Bug/Report.html?Queue=Games-ABC_Path-Solver>. You will be automatically notified of any
+progress on the request by the system.
+
+=head2 Source Code
+
+The code is open to the world, and available for you to hack on. Please feel free to browse it and play
+with it, or whatever. If you want to contribute patches, please send me a diff or prod me to pull
+from your repository :)
+
+L<https://github.com/shlomif/games-abc_path-solver>
+
+  git clone https://github.com/shlomif/abc-path
 
 =cut
-
-1; # End of Games::ABC_Path::Solver::Board
